@@ -13,12 +13,21 @@ from __future__ import absolute_import
 
 import datetime
 import logging
+import socket
 import os
 import time
-import urllib2
+import zlib
+from opbeat.utils import six
+try:
+    from urllib2 import HTTPError
+except ImportError:
+    from urllib.error import HTTPError
 import uuid
 import warnings
-from urlparse import urlparse
+try:
+    import urlparse
+except ImportError:
+    from urllib import parse as urlparse
 
 import opbeat
 from opbeat.conf import defaults
@@ -33,49 +42,49 @@ __all__ = ('Client',)
 
 
 class ModuleProxyCache(dict):
-	def __missing__(self, key):
-		module, class_name = key.rsplit('.', 1)
+    def __missing__(self, key):
+        module, class_name = key.rsplit('.', 1)
 
-		handler = getattr(__import__(module, {},
-				{}, [class_name], -1), class_name)
+        handler = getattr(__import__(module, {},
+                {}, [class_name]), class_name)
 
-		self[key] = handler
+        self[key] = handler
 
-		return handler
+        return handler
 
 
 class ClientState(object):
-	ONLINE = 1
-	ERROR = 0
+    ONLINE = 1
+    ERROR = 0
 
-	def __init__(self):
-		self.status = self.ONLINE
-		self.last_check = None
-		self.retry_number = 0
+    def __init__(self):
+        self.status = self.ONLINE
+        self.last_check = None
+        self.retry_number = 0
 
-	def should_try(self):
-		if self.status == self.ONLINE:
-			return True
+    def should_try(self):
+        if self.status == self.ONLINE:
+            return True
 
-		interval = min(self.retry_number, 6) ** 2
+        interval = min(self.retry_number, 6) ** 2
 
-		if time.time() - self.last_check > interval:
-			return True
+        if time.time() - self.last_check > interval:
+            return True
 
-		return False
+        return False
 
-	def set_fail(self):
-		self.status = self.ERROR
-		self.retry_number += 1
-		self.last_check = time.time()
+    def set_fail(self):
+        self.status = self.ERROR
+        self.retry_number += 1
+        self.last_check = time.time()
 
-	def set_success(self):
-		self.status = self.ONLINE
-		self.last_check = None
-		self.retry_number = 0
+    def set_success(self):
+        self.status = self.ONLINE
+        self.last_check = None
+        self.retry_number = 0
 
-	def did_fail(self):
-		return self.status == self.ERROR
+    def did_fail(self):
+        return self.status == self.ERROR
 
 
 class Client(object):
@@ -140,12 +149,12 @@ class Client(object):
         # servers may be set to a NoneType (for Django)
         if self.servers and not (organization_id and app_id and secret_token):
             msg = 'Missing configuration for client. Please see documentation.'
-            raise TypeError(msg)
+            self.logger.info(msg)
 
         self.include_paths = set(include_paths or defaults.INCLUDE_PATHS)
         self.exclude_paths = set(exclude_paths or defaults.EXCLUDE_PATHS)
         self.timeout = int(timeout or defaults.TIMEOUT)
-        self.hostname = unicode(hostname or defaults.HOSTNAME)
+        self.hostname = six.text_type(hostname or defaults.HOSTNAME)
         self.auto_log_stacks = bool(auto_log_stacks or
                 defaults.AUTO_LOG_STACKS)
 
@@ -213,7 +222,7 @@ class Client(object):
         if data.get('culprit'):
             culprit = data['culprit']
 
-        for k, v in result.iteritems():
+        for k, v in six.iteritems(result):
             if k not in data:
                 data[k] = v
 
@@ -241,13 +250,13 @@ class Client(object):
         if not data.get('level'):
             data['level'] = 'error'
 
-        if isinstance( data['level'], ( int, long ) ):
+        if isinstance( data['level'], six.integer_types):
             data['level'] = logging.getLevelName(data['level']).lower()
 
         data.setdefault('extra', {})
 
         # Shorten lists/strings
-        for k, v in extra.iteritems():
+        for k, v in six.iteritems(extra):
             data['extra'][k] = shorten(v, string_length=self.string_max_length,
                     list_length=self.list_max_length)
 
@@ -290,7 +299,7 @@ class Client(object):
     def capture(self, event_type, data=None, date=None, api_path=None,
                 extra=None, stack=None, **kwargs):
         """
-        Captures and processes an event and pipes it off to SentryClient.send.
+        Captures and processes an event and pipes it off to Client.send.
 
         To use structured data (interfaces) with capture:
 
@@ -346,10 +355,12 @@ class Client(object):
 
         return data['client_supplied_id']
 
-    def _send_remote(self, url, data, headers={}):
-        parsed = urlparse(url)
+    def _send_remote(self, url, data, headers=None):
+        if headers is None:
+            headers = {}
+        parsed = urlparse.urlparse(url)
         transport = self._registry.get_transport(parsed)
-        return transport.send(data, headers)
+        return transport.send(data, headers, timeout=self.timeout)
 
     def _get_log_message(self, data):
         # decode message so we can show the actual event
@@ -361,7 +372,7 @@ class Client(object):
             message = data.pop('message', '<no message value>')
         return message
 
-    def send_remote(self, url, data, headers={}):
+    def send_remote(self, url, data, headers=None):
         if not self.state.should_try():
             message = self._get_log_message(data)
             self.error_logger.error(message)
@@ -369,8 +380,13 @@ class Client(object):
 
         try:
             self._send_remote(url=url, data=data, headers=headers)
-        except Exception, e:
-            if isinstance(e, urllib2.HTTPError):
+        except Exception as e:
+            if isinstance(e, socket.timeout):
+                self.error_logger.error("Connection to Opbeat server timed out (url: %s, timeout: %d seconds)" % (
+                    url,
+                    self.timeout,
+                ), exc_info=True, extra={'data': {'remote_url': url}})
+            elif isinstance(e, HTTPError):
                 body = e.read()
                 self.error_logger.error('Unable to reach Opbeat server: %s (url: %%s, body: %%s)' % (e,), url, body,
                     exc_info=True, extra={'data': {'body': body, 'remote_url': url}})
@@ -442,13 +458,14 @@ class Client(object):
         """
         Serializes ``data`` into a raw string.
         """
-        return json.dumps(data).encode('zlib')
+        # return json.dumps(data).encode('zlib')
+        return zlib.compress(json.dumps(data).encode('utf8'))
 
     def decode(self, data):
         """
         Unserializes a string, ``data``.
         """
-        return json.loads(data.decode('zlib'))
+        return json.loads(zlib.decompress(data).decode('utf8'))
 
     def captureMessage(self, message, **kwargs):
         """
