@@ -1,9 +1,15 @@
 # -*- coding: utf-8 -*-
 
 import mock
-from unittest2 import TestCase
-from celery.tests.utils import with_eager_tasks
 from opbeat.contrib.celery import CeleryClient
+from opbeat.utils.compat import skipIf, TestCase
+
+try:
+    from celery.tests.utils import with_eager_tasks
+    has_with_eager_tasks = True
+except ImportError:
+    from opbeat.utils.compat import noop_decorator as with_eager_tasks
+    has_with_eager_tasks = False
 
 
 class ClientTest(TestCase):
@@ -30,6 +36,7 @@ class ClientTest(TestCase):
 
         self.assertEquals(send_raw.delay.call_count, 1)
 
+    @skipIf(not has_with_eager_tasks, 'with_eager_tasks is not available')
     @with_eager_tasks
     @mock.patch('opbeat.base.Client.send_encoded')
     def test_with_eager(self, send_encoded):
